+++
title = "Using Org macros in lieu of Hugo shortcodes"
description = """
  Using Org macros in place of Hugo shortcodes to make the Org content
  reusable across more export backends.
  """
tags = ["shortcode"]
draft = false
+++

`ox-hugo` Issue #[303](https://github.com/kaushalmodi/ox-hugo/issues/303)

The `youtube` Org macros used here kind of mimics the Hugo shortcode
[**youtube**](https://github.com/gohugoio/hugo/blob/00297085db48cbb7949c9867012f6df38817fc29/tpl/tplimpl/embedded/templates/shortcodes/youtube.html).

<div class="org-youtube"><iframe src="https://www.youtube-nocookie.com/embed/v_jDFgS2AqE" allowfullscreen title="YouTube Video"></iframe></div>
